@@ -108,8 +108,8 @@ class TestWriteTags(unittest.TestCase):
 class TestWriteNode(unittest.TestCase):
 
     def test_location_tuple(self):
-        with WriteExpect('n0 v0 dV c0 t i0 u T x1.0000000 y2.0000000') as w:
-            w.add_node(O(location=(1, 2)))
+        with WriteExpect('n0 v0 dV c0 t i0 u T x1.1234561 y0.1234561') as w:
+            w.add_node(O(location=(1.1234561, 0.1234561)))
 
     def test_location_none(self):
         with WriteExpect('n0 v0 dV c0 t i0 u T x y') as w:
